==> haskell-tagstream-conduit-0.5.5.3-52-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagstream-conduit
version: 0.5.5.3
id: tagstream-conduit-0.5.5.3-EIQ0bbCXC1R43V9CboBVXW
key: tagstream-conduit-0.5.5.3-EIQ0bbCXC1R43V9CboBVXW
license: BSD3
maintainer: yi.codeplayer@gmail.com
homepage: http://github.com/yihuang/tagstream-conduit
synopsis: streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.
category: Web, Conduit
author: yihuang
exposed: True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Text Text.HTML.TagStream.Types
    Text.HTML.TagStream.Utils Text.HTML.TagStream.Entities
abi: 94dcdb0eb57858c27a74b1e78d0ccb64
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/tagstream-conduit-0.5.5.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/tagstream-conduit-0.5.5.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/tagstream-conduit-0.5.5.3
hs-libraries: HStagstream-conduit-0.5.5.3-EIQ0bbCXC1R43V9CboBVXW
depends:
    attoparsec-0.13.1.0-IbZnQWsljer1cy7HS9Csat base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.7-43Vuzc2uQwC59iyLU6pVOg
    conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-824iGXaP3tL2Ph4TH8girc
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    xml-conduit-1.4.0.3-1bd8KNJaq8DDj7hfPl9EFB
haddock-interfaces: /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock
haddock-html: /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagstream-conduit-0.5.5.3-64-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tagstream-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tagstream-conduit
version: 0.5.5.3
id: tagstream-conduit-0.5.5.3-9cPC4Zz7yTxGIBYwfNTkRW
key: tagstream-conduit-0.5.5.3-9cPC4Zz7yTxGIBYwfNTkRW
license: BSD3
maintainer: yi.codeplayer@gmail.com
homepage: http://github.com/yihuang/tagstream-conduit
synopsis: streamlined html tag parser
description:
    Tag-stream is a library for parsing HTML//XML to a token stream.
    It can parse unstructured and malformed HTML from the web.
    It also provides an Enumeratee which can parse streamline html, which means it consumes constant memory.
    You can start from the `tests/Tests.hs` module to see what it can do.
category: Web, Conduit
author: yihuang
exposed: True
exposed-modules:
    Text.HTML.TagStream Text.HTML.TagStream.ByteString
    Text.HTML.TagStream.Text Text.HTML.TagStream.Types
    Text.HTML.TagStream.Utils Text.HTML.TagStream.Entities
abi: 0c81d5b0aeff3c5ec08ec675bf051a9a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/tagstream-conduit-0.5.5.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/tagstream-conduit-0.5.5.3
data-dir: /usr/share/i386-linux-ghc-8.0.1/tagstream-conduit-0.5.5.3
hs-libraries: HStagstream-conduit-0.5.5.3-9cPC4Zz7yTxGIBYwfNTkRW
depends:
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF bytestring-0.10.8.1
    case-insensitive-1.2.0.8-19yABacCVqnEmCaYKTVngi
    conduit-1.2.10-JpwcbBZZrSj1n2q4Mh3BJS
    conduit-extra-1.1.15-6XNZLygDeFX2HjFkbmIzsS
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
    xml-conduit-1.4.0.4-4JMNsrmqa8CJ6lSm2Ik1gQ
haddock-interfaces: /usr/share/doc/haskell-tagstream-conduit/html/tagstream-conduit.haddock
haddock-html: /usr/share/doc/haskell-tagstream-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
